==> bibledit-0.7.tar.gz: bibledit-0.7/src/pdfviewer.cpp <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "pdfviewer.h"
#include <gtk/gtk.h>


#define NUMBER_OF_VIEWERS 5


string pdf_binary (int index)
{
  // Returns a command to be executed to view pdf files.
  // Variabele "index" selects which viewer will be used.
  string command;
  switch (index)
    {
    case 0:
      {
        command = "xpdf";
        break;
      }
    case 1:
      {
        command = "ghostview";
        break;
      }
    case 2:
      {
        command = "gpdf";
        break;
      }
    case 3:
      {
        command = "kpdf";
        break;
      }
    case 4:
      {
        command = "kghostview";
        break;
      }
      // Note: when adding new browsers, ensure that the variabele
      // NUMBER_OF_VIEWERS is updated too.
    }
  return command;
}


void
pdfviewer (const string filename)
{

  for (unsigned int i = 0; i < NUMBER_OF_VIEWERS; i++)
    {
      string command;
      command = "which ";
      command.append (pdf_binary (i));
      command.append (" > /dev/null 2>&1");
      if (system (command.c_str ()) == 0)
        {
          command = pdf_binary (i);
          command.append (" '");
          command.append (filename);
          command.append ("' > /dev/null &");
          system (command.c_str ());
          return;
        }
    }
  // If we're here, it shows that no suitable viewer was found.
  // Inform the user about it, and what to do to solve it.
  string message;
  message =
    "The file cannot be displayed, because there is no suitable pdf viewer installed.\n";
  message.append ("Install one of the following supported pdf viewers:\n");
  for (unsigned int i = 0; i < NUMBER_OF_VIEWERS; i++) {
    message.append (pdf_binary (i));
    message.append ("\n");
  }
  GtkWidget *dialog = gtk_message_dialog_new (NULL,
                                              GTK_DIALOG_DESTROY_WITH_PARENT,
                                              GTK_MESSAGE_ERROR,
                                              GTK_BUTTONS_OK,
                                              message.c_str ());
  gtk_dialog_run (GTK_DIALOG (dialog));
  gtk_widget_destroy (dialog);
}

==> bibledit-0.9.tar.gz: bibledit-0.9/src/pdfviewer.cpp <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "libraries.h"
#include "pdfviewer.h"
#include <gtk/gtk.h>


#define NUMBER_OF_VIEWERS 5


string pdf_binary (int index, bool full)
{
  // Returns a command to be executed to view pdf files.
  // Variabele "index" selects which viewer will be used.
  // When "full", additional switches, appropriate for that viewer, are added.
  string command;
  switch (index)
    {
    case 0:
      {
        if (full)
          command = "xpdf -paper match";
        else
          command = "xpdf";
        break;
      }
    case 1:
      {
        command = "ghostview";
        break;
      }
    case 2:
      {
        command = "gpdf";
        break;
      }
    case 3:
      {
        command = "kpdf";
        break;
      }
    case 4:
      {
        command = "kghostview";
        break;
      }
      // Note: when adding new browsers, ensure that the variabele
      // NUMBER_OF_VIEWERS is updated too.
    }
  return command;
}


void
pdfviewer (const string filename)
{

  for (unsigned int i = 0; i < NUMBER_OF_VIEWERS; i++)
    {
      string command;
      command = "which ";
      command.append (pdf_binary (i, false));
      command.append (" > /dev/null 2>&1");
      if (system (command.c_str ()) == 0)
        {
          command = pdf_binary (i, true);
          command.append (" '");
          command.append (filename);
          command.append ("' > /dev/null &");
          system (command.c_str ());
          return;
        }
    }
  // If we're here, it shows that no suitable viewer was found.
  // Inform the user about it, and what to do to solve it.
  string message;
  message =
    "The file cannot be displayed, because there is no suitable pdf viewer installed.\n";
  message.append ("Install one of the following supported pdf viewers:\n");
  for (unsigned int i = 0; i < NUMBER_OF_VIEWERS; i++) {
    message.append (pdf_binary (i, false));
    message.append ("\n");
  }
  GtkWidget *dialog = gtk_message_dialog_new (NULL,
                                              GTK_DIALOG_DESTROY_WITH_PARENT,
                                              GTK_MESSAGE_ERROR,
                                              GTK_BUTTONS_OK,
                                              message.c_str ());
  gtk_dialog_run (GTK_DIALOG (dialog));
  gtk_widget_destroy (dialog);
}
